@@ -9,7 +9,7 @@ ALL_STATES = '{}' + _COVID_BASE + '/states'
 SINGLE_STATE = ALL_STATES + '/{}'
 
 HISTORICAL_COUNTRY = '{}' + _COVID_BASE + '/historical/{}'
-HISTORICAL_PROVINCE = HISTORICAL_COUNTRY + '/historical/{}'
+HISTORICAL_PROVINCE = HISTORICAL_COUNTRY + '/{}'
 STATE_COUNTY = '{}' + _COVID_BASE + '/historical/usacounties/{}'
 
 ALL_CONTINENTS = '{}' + _COVID_BASE + '/continents'
